@@ -20,7 +20,8 @@ input.input-for-variable.validation-warn {
 table tr td button.placeholder-input-apply-button,
 table tr td input.input-for-variable,
 table tr td select.placeholder-dropdown {
-    min-width: max(200px, 100%);
+    min-width: min(30vw, 200px);
+    max-width: initial;
 }
 
 table tr td input.input-for-variable[type="checkbox"] {
@@ -51,7 +52,25 @@ MATERIAL_STYLE = """
 }
 """
 
-def generate_style_sheet(theme_name: str):
+HIGHLIGHT_STYLE = """
+.placeholder-value {
+    background-color: #aaa;
+    padding: 3px;
+    border-radius: 3px;
+}
+"""
+
+def generate_style_sheet(theme_name: str, debug: bool):
+    theme = _generate_theme_style_sheet(theme_name)
+    
+    if debug:
+        # For highlighting stuff, useful during debugging
+        theme += HIGHLIGHT_STYLE
+
+    return theme
+
+
+def _generate_theme_style_sheet(theme_name: str):
     if theme_name == "material":
         # MkDocs for Material screws up the look of imput elements (makes them look really bad)
         # So I implemented some rough fixes that should fit in with the users color choices
